@@ -30,6 +30,7 @@ pub(crate) struct Recipe<'src, D = Dependency<'src>> {
   pub(crate) private: bool,
   pub(crate) quiet: bool,
   pub(crate) shebang: bool,
+  pub(crate) suppress_exit_error_messages: bool,
 }
 
 impl<'src, D> Recipe<'src, D> {
@@ -191,10 +192,12 @@ impl<'src, D> Recipe<'src, D> {
         Ok(exit_status) => {
           if let Some(code) = exit_status.code() {
             if code != 0 && !infallible_command {
+              let suppress_message = self.suppress_exit_error_messages;
               return Err(Error::Code {
                 recipe: self.name(),
                 line_number: Some(line_number),
                 code,
+                suppress_message,
               });
             }
           } else {
@@ -247,15 +250,17 @@ impl<'src, D> Recipe<'src, D> {
       message: format!("bad shebang line: {}", shebang_line),
     })?;
 
-    let tmp = tempfile::Builder::new()
-      .prefix("just")
-      .tempdir()
-      .map_err(|error| Error::TmpdirIo {
-        recipe: self.name(),
-        io_error: error,
-      })?;
-    let mut path = tmp.path().to_path_buf();
-
+    let mut tempdir_builder = tempfile::Builder::new();
+    tempdir_builder.prefix("just");
+    let tempdir = match &context.settings.tempdir {
+      Some(tempdir) => tempdir_builder.tempdir_in(context.search.working_directory.join(tempdir)),
+      None => tempdir_builder.tempdir(),
+    }
+    .map_err(|error| Error::TmpdirIo {
+      recipe: self.name(),
+      io_error: error,
+    })?;
+    let mut path = tempdir.path().to_path_buf();
     path.push(shebang.script_filename(self.name()));
 
     {
@@ -322,10 +327,12 @@ impl<'src, D> Recipe<'src, D> {
           if code == 0 {
             Ok(())
           } else {
+            let suppress_message = self.suppress_exit_error_messages;
             Err(Error::Code {
               recipe: self.name(),
               line_number: None,
               code,
+              suppress_message,
             })
           }
         },
