@@ -5,7 +5,7 @@ pub(crate) const DEFAULT_SHELL_ARGS: &[&str] = &["-cu"];
 pub(crate) const WINDOWS_POWERSHELL_SHELL: &str = "powershell.exe";
 pub(crate) const WINDOWS_POWERSHELL_ARGS: &[&str] = &["-NoLogo", "-Command"];
 
-#[derive(Debug, PartialEq, Serialize, Default)]
+#[derive(Debug, PartialEq, Serialize)]
 pub(crate) struct Settings<'src> {
   pub(crate) allow_duplicate_recipes: bool,
   pub(crate) dotenv_load: Option<bool>,
@@ -14,6 +14,7 @@ pub(crate) struct Settings<'src> {
   pub(crate) ignore_comments: bool,
   pub(crate) positional_arguments: bool,
   pub(crate) shell: Option<Shell<'src>>,
+  pub(crate) tempdir: Option<String>,
   pub(crate) windows_powershell: bool,
   pub(crate) windows_shell: Option<Shell<'src>>,
 }
@@ -66,6 +67,23 @@ impl<'src> Settings<'src> {
   }
 }
 
+impl<'src> Default for Settings<'src> {
+  fn default() -> Self {
+    Self {
+      allow_duplicate_recipes: false,
+      dotenv_load: None,
+      export: false,
+      fallback: true,
+      ignore_comments: false,
+      positional_arguments: false,
+      shell: None,
+      tempdir: None,
+      windows_powershell: false,
+      windows_shell: None,
+    }
+  }
+}
+
 #[cfg(test)]
 mod tests {
   use super::*;
