@@ -36,15 +36,17 @@ fn alias() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
@@ -73,10 +75,11 @@ fn assignment() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -111,16 +114,18 @@ fn body() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -154,6 +159,7 @@ fn dependencies() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "foo": {
           "body": [],
@@ -165,16 +171,18 @@ fn dependencies() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -238,6 +246,7 @@ fn dependency_argument() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "foo": {
           "body": [],
@@ -256,16 +265,18 @@ fn dependency_argument() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -311,16 +322,18 @@ fn duplicate_recipes() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": true,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -348,16 +361,18 @@ fn doc_comment() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -379,10 +394,11 @@ fn empty_justfile() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -417,6 +433,7 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "b": {
           "body": [],
@@ -435,6 +452,7 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "c": {
           "body": [],
@@ -453,6 +471,7 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "d": {
           "body": [],
@@ -471,6 +490,7 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "e": {
           "body": [],
@@ -489,6 +509,7 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "f": {
           "body": [],
@@ -507,16 +528,18 @@ fn parameters() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -548,6 +571,7 @@ fn priors() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         },
         "b": {
           "body": [],
@@ -566,6 +590,7 @@ fn priors() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
           "parameters": [],
           "priors": 1,
         },
@@ -578,6 +603,7 @@ fn priors() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
           "parameters": [],
           "priors": 0,
         },
@@ -586,10 +612,11 @@ fn priors() {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -617,16 +644,18 @@ fn private() {
           "private": true,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -654,16 +683,18 @@ fn quiet() {
           "private": false,
           "quiet": true,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir" : null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -692,7 +723,6 @@ fn settings() {
       set positional-arguments
       set ignore-comments
       set shell := ['a', 'b', 'c']
-
       foo:
         #!bar
     ",
@@ -711,6 +741,7 @@ fn settings() {
           "private": false,
           "quiet": false,
           "shebang": true,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
@@ -724,6 +755,7 @@ fn settings() {
           "arguments": ["b", "c"],
           "command": "a",
         },
+        "tempdir": null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -754,16 +786,18 @@ fn shebang() {
           "private": false,
           "quiet": false,
           "shebang": true,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
         "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir": null,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -791,15 +825,59 @@ fn simple() {
           "private": false,
           "quiet": false,
           "shebang": false,
+          "suppress_exit_error_messages": false,
         }
       },
       "settings": {
         "allow_duplicate_recipes": false,
         "dotenv_load": null,
         "export": false,
-        "fallback": false,
+        "fallback": true,
+        "ignore_comments": false,
         "positional_arguments": false,
         "shell": null,
+        "tempdir": null,
+        "windows_powershell": false,
+        "windows_shell": null,
+      },
+      "warnings": [],
+    }),
+  );
+}
+
+#[test]
+fn attribute() {
+  test(
+    "
+      [no-exit-message]
+      foo:
+    ",
+    json!({
+      "aliases": {},
+      "assignments": {},
+      "first": "foo",
+      "recipes": {
+        "foo": {
+          "body": [],
+          "dependencies": [],
+          "doc": null,
+          "name": "foo",
+          "parameters": [],
+          "priors": 0,
+          "private": false,
+          "quiet": false,
+          "shebang": false,
+          "suppress_exit_error_messages": true,
+        }
+      },
+      "settings": {
+        "allow_duplicate_recipes": false,
+        "dotenv_load": null,
+        "export": false,
+        "fallback": true,
+        "positional_arguments": false,
+        "shell": null,
+        "tempdir" : null,
         "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
